Unit TPDBHigh;


                           (************************)
                           (*    TPDBHigh.pas      *)
                           (* A unit of high level *)
                           (* calls to routines in *)
                           (* TPDB.pas.            *)
                           (*   TPDB Version 2.2   *)
                           (*   Copyright 1989     *)
                           (*      Brian Corll     *)
                           (*     March 2, 1989    *)
                           (************************)


INTERFACE

Uses TPDB;

Var
   TPOk : Boolean;

Procedure CloseFiles;
{Close currently open .DBF file and associated
 master index.}

Procedure Delete(KeyField : Byte);
{Marks a record for deletion and deletes its associated key in
 the master index.  KeyField is the number of the key field as it
 appears in the .DBF structure. }

Procedure FlushFiles;
{Flush .DBF file and its associated master index.}

Procedure Insert(KeyField : Byte);
{Add a new record to a .DBF file, and add the key to the associated
 master index.  KeyField is the number of the key field as it appears
 in the .DBF structure.}

Procedure OpenFiles(DBName : FileName;IndexName : FileName;
          KeyLen,Status : Integer);
{Open A .DBF file and its associated master index. KeyLen is the length of
 the key field or fields.  Status is either 0 (no duplicate keys) or 1
 (duplicate keys allowed).}

Procedure Search(KeyStr : string;ExactOn : Boolean);
{Find a key string in an index and, if found, load the associated .DBF record
 into memory for editing;}

Procedure UpDate(KeyField : Byte);
{Write an existing record to disk after editing, and update the
 master index.}



IMPLEMENTATION

Var
   DBFName,IndName : FileName;
   KLen,Stat : Integer;

Procedure CloseFiles;
{Close .DBF and master index files.}
begin
     CloseDBFile;
     CloseDBIndex;
end;

Procedure Delete(KeyField : Byte);
begin
     Mark;
     PutDBRec(DBRecNum);
     DelDBKey(FieldToStr(KeyField));
end;

Procedure FlushFiles;
begin
     CloseFiles;
     OpenFiles(DBFName,IndName,KLen,Stat);
end;

Procedure Insert(KeyField : Byte);
{Add a new record, and insert new key in index.}
begin
    AddDBRec;
    AddDBKey(FieldToStr(KeyField));
end;

Procedure OpenFiles(DBName : FileName;IndexName : FileName;
          KeyLen,Status : Integer);
{Open .DBF and master index files.}
begin
     DBOpenFile(DBName);
     OpenDBIndex(IndexName,KeyLen,Status);
     DBFName := DBName;
     IndName := IndexName;
     KLen := KeyLen;
     Stat := Status;
end;

Procedure Search(KeyStr : string;ExactOn : Boolean);
{Find a record}
begin
     If ExactOn then
        Find(KeyStr)
     else
         LookUp(KeyStr);
     If Found then TPOk := True
     else TPOk := False;
end;

Procedure UpDate(KeyField : Byte);
{Update an existing record.}
begin
     AddDBKey(FieldToStr(KeyField));
     PutDBRec(DBRecNum);
end;





begin
end.



